==> vscat-1.0.0.tgz: package/tests/highlighting/diagnostics/html/tag-error/results/output.visual-studio-light.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-error test visual-studio-light theme 1`] = `
Object {
  "lines": Array [
    "[48;2;255;255;255m [38;2;35;120;147m 1 │ [39m[38;2;128;0;0m<html>[39m                                                                    [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 2 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<head>[39m                                                                  [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 3 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<meta[39m[38;2;214;214;214m·[39m[38;2;255;0;0mfoo[39m[38;2;0;0;0m=[39m[38;2;0;0;255m\\"bar\\"[39m[38;2;214;214;214m·[39m[38;2;128;0;0m/>[39m                                                    [49m",
    "[48;2;255;255;255m   [38;2;35;120;147m │ [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;214;214;214m [39m[38;2;229;20;0m~~~[39m                                                             [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 4 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<meta[39m[38;2;214;214;214m·[39m[38;2;255;0;0mcharset[39m[38;2;0;0;0m=[39m[38;2;0;0;255m\\"utf-8\\"[39m[38;2;214;214;214m·[39m[38;2;128;0;0m/>[39m                                              [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 5 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<title>[39m[38;2;0;0;0mmy[39m[38;2;214;214;214m·[39m[38;2;0;0;0mpage[39m[38;2;128;0;0m</title>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 6 │ #800000 │ <html>
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #800000 │ <head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  4, 9 │ #800000 │ <meta
 2 │ 10,13 │ #FF0000 │ foo
 2 │ 13,14 │ ─────── │ =
 2 │ 14,19 │ #0000FF │ \\"bar\\"
 2 │ 20,22 │ #800000 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  4, 9 │ #800000 │ <meta
 3 │ 10,17 │ #FF0000 │ charset
 3 │ 17,18 │ ─────── │ =
 3 │ 18,25 │ #0000FF │ \\"utf-8\\"
 3 │ 26,28 │ #800000 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  4,11 │ #800000 │ <title>
 4 │ 11,13 │ ─────── │ my
 4 │ 14,18 │ ─────── │ page
 4 │ 18,26 │ #800000 │ </title>
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2, 9 │ #800000 │ </head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2, 8 │ #800000 │ <body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,11 │ ─────── │ Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  2, 9 │ #800000 │ </body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 7 │ #800000 │ </html>
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/diagnostics/html/tag-error/results/output.visual-studio-light.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-error test visual-studio-light theme 1`] = `
Object {
  "lines": Array [
    "[48;2;255;255;255m [38;2;35;120;147m 1 │ [39m[38;2;128;0;0m<html>[39m                                                                    [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 2 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<head>[39m                                                                  [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 3 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<meta[39m[38;2;214;214;214m·[39m[38;2;255;0;0mfoo[39m[38;2;0;0;0m=[39m[38;2;0;0;255m\\"bar\\"[39m[38;2;214;214;214m·[39m[38;2;128;0;0m/>[39m                                                    [49m",
    "[48;2;255;255;255m   [38;2;35;120;147m │ [39m[38;2;0;0;0m          [39m[38;2;229;20;0m~~~[39m                                                             [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 4 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<meta[39m[38;2;214;214;214m·[39m[38;2;255;0;0mcharset[39m[38;2;0;0;0m=[39m[38;2;0;0;255m\\"utf-8\\"[39m[38;2;214;214;214m·[39m[38;2;128;0;0m/>[39m                                              [49m",
    "[48;2;255;255;255m [38;2;35;120;147m 5 │ [39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;214;214;214m·[39m[38;2;128;0;0m<title>[39m[38;2;0;0;0mmy[39m[38;2;214;214;214m·[39m[38;2;0;0;0mpage[39m[38;2;128;0;0m</title>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 6 │ #800000 │ <html>
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #800000 │ <head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  4, 9 │ #800000 │ <meta
 2 │ 10,13 │ #FF0000 │ foo
 2 │ 13,14 │ ─────── │ =
 2 │ 14,19 │ #0000FF │ \\"bar\\"
 2 │ 20,22 │ #800000 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  4, 9 │ #800000 │ <meta
 3 │ 10,17 │ #FF0000 │ charset
 3 │ 17,18 │ ─────── │ =
 3 │ 18,25 │ #0000FF │ \\"utf-8\\"
 3 │ 26,28 │ #800000 │ />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  4,11 │ #800000 │ <title>
 4 │ 11,13 │ ─────── │ my
 4 │ 14,18 │ ─────── │ page
 4 │ 18,26 │ #800000 │ </title>
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2, 9 │ #800000 │ </head>
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2, 8 │ #800000 │ <body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,11 │ ─────── │ Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  2, 9 │ #800000 │ </body>
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 7 │ #800000 │ </html>
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;
